@@ -1,3 +1,6 @@
+import os
+import shutil
+import atexit
 import contextlib
 import subprocess
 
@@ -19,6 +22,8 @@ def TestServer(users={}, indices={}, config={}):
             'serverdir' : server_dir}
         server_options.update(config)
 
+        prefill_serverdir(server_options)
+
         with DevpiServer(server_options) as url:
             with DevpiClient(url, 'root', '') as client:
 
@@ -39,3 +44,24 @@ def DevpiServer(options):
             yield 'http://localhost:{}'.format(options['port'])
         finally:
             subprocess.check_output(['devpi-server', '--stop'] + args, stderr=subprocess.STDOUT)
+
+
+serverdir_cache = '/tmp/devpi-plumber-cache'
+atexit.register(shutil.rmtree, serverdir_cache, ignore_errors=True)
+
+
+def prefill_serverdir(server_options):
+    """
+    Starting a new devpi-server is costly due to its initial sync with pypi.python.org.
+    We can speedup this process by using the content of a cached serverdir.
+    """
+    serverdir_new = server_options['serverdir']
+
+    if 'master-url' in server_options:
+        return # always has to be a fresh sync
+    elif os.path.exists(serverdir_cache):
+        shutil.rmtree(serverdir_new)
+        shutil.copytree(serverdir_cache, serverdir_new)
+    else:
+        with DevpiServer(server_options):
+            shutil.copytree(serverdir_new, serverdir_cache)
